Invenio modules (alpha)
-----------------------
.. note::

    These modules are in alpha. The modules are being used in production
    systems but are most likely subject to changes and are missing
    documentation.

In addition to above bundles, we have a number of other individual modules
which are all being used in production systems, but which are likely subject
to change prior to final release and in most cases are missing documentation.

- `invenio-accounts-rest <https://invenio-accounts-rest.readthedocs.io>`_
    - REST APIs for account management.
- `invenio-app-rdm <https://inveniordm.docs.cern.ch>`_
    - Research Data Management (RDM) flavour of Invenio
- `invenio-app-ils <https://invenio-app-ils.readthedocs.io>`_
    - Integrated Library System (ILS) flavour of Invenio.
- `invenio-banners <https://invenio-banners.readthedocs.io>`_
    - Create and show banners with useful messages to users.
- `invenio-charts-js <https://invenio-charts-js.readthedocs.io>`_
    - AngularJS application for producing charts.
- `invenio-circulation <https://invenio-circulation.readthedocs.io>`_
    - Library circulation module for Invenio.
- `invenio-cli <https://inveniordm.docs.cern.ch/reference/cli/>`_
    - CLI module for Invenio
- `invenio-communities <https://invenio-communities.readthedocs.io>`_
    - Invenio communities module.
- `invenio-csl-js <https://invenio-csl-js.readthedocs.io>`_
    - AngularJS application for rendering citation strings via the records
      REST API and the CSL REST API.
- `invenio-csl-rest <https://invenio-csl-rest.readthedocs.io>`_
    - REST API for retrieving Citation Style Language (CSL) style files.
- `invenio-drafts-resources <https://invenio-drafts-resources.readthedocs.io>`_
    - Submission/deposit module for Invenio.
- `invenio-github <https://invenio-github.readthedocs.io>`_
    - GitHub integration with automatic archiving of new releases in Invenio.
- `invenio-migrator <https://invenio-migrator.readthedocs.io>`_
    - Utilities for migrating past Invenio versions to Invenio 3.0.
- `invenio-oaiharvester <https://invenio-oaiharvester.readthedocs.io>`_
    - Invenio module for OAI-PMH metadata harvesting between repositories.
- `invenio-openaire <https://invenio-openaire.readthedocs.io>`_
    - Integration with OpenAIRE, including support for harvesting Open Funder
      Regsitry and the OpenAIRE grants database, as well as REST APIs for
      funders and grants.
- `invenio-opendefinition <https://invenio-opendefinition.readthedocs.io>`_
    - REST API for licenses from OpenDefinition and SPDX.
- `invenio-pages <https://invenio-pages.readthedocs.io>`_
    - Static pages module for Invenio.
- `invenio-pidrelations <https://invenio-pidrelations.readthedocs.io>`_
    - Persistent identifier relations management to support e.g. DOI
      versioning.
- `invenio-previewer-ispy <https://invenio-previewer-ispy.readthedocs.io>`_
    - ISPY previewer.
- `invenio-query-parser <https://invenio-query-parser.readthedocs.io>`_
    - Invenio v1 compatible query parser for Invenio v3. Note the module is GPL
      licensed due to a GPL-licensed dependency.
- `invenio-records-editor <https://invenio-records-editor.readthedocs.io>`_
    - Record editor for Invenio (Python part).
- `invenio-records-editor-js <https://invenio-records-editor-js.readthedocs.io>`_
    - Record editor for Invenio (JavaScript part).
- `invenio-records-permissions <https://invenio-records-permissions.readthedocs.io>`_
    - Permissions for Invenio's records REST API.
- `invenio-records-resources <https://invenio-records-resources.readthedocs.io>`_
    - Records REST APIs for Invenio.
- `invenio-rdm-records <https://invenio-rdm-records.readthedocs.io>`_
    - DataCite-based data model for InvenioRDM flavour.
- `invenio-s3 <https://invenio-s3.readthedocs.io>`_
    - Support for the S3 storage protocol in Invenio.
- `invenio-saml <https://invenio-saml.readthedocs.io>`_
    - SAML support for Invenio.
- `invenio-sequencegenerator <https://invenio-sequencegenerator.readthedocs.io>`_
    - Module for minting and tracking multiple sequences for e.g. report
      numbers, journals etc.
- `invenio-sse <https://invenio-sse.readthedocs.io>`_
    - Server-Sent Events (SSE) integration in Invenio.
- `invenio-webhooks <https://invenio-webhooks.readthedocs.io>`_
    - REST API for receiving and processing webhook calls from third-party
      services.
- `invenio-xrootd <https://invenio-xrootd.readthedocs.io>`_
    - Support for the storage protocol XRootD in Invenio.
- `react-invenio-app-ils <https://react-invenio-app-ils.readthedocs.io>`_
    - Single Page App built with React for InvenioILS.
- `react-invenio-deposit <https://react-invenio-deposit.readthedocs.io>`_
    - React application for Invenio deposit forms.
- `react-invenio-forms <https://react-invenio-forms.readthedocs.io>`_
    - React component library for Formik components.
- `react-searchkit <https://invenio-react-searchkit.readthedocs.io>`_
    - Modular React library for implementing search interfaces on top of
      Invenio, Elasticsearch or other search APIs. Replacement for
      Invenio-Search-JS.
